{% extends "base.html" %}

{% block title %}Unavailable{% endblock %}

{% block content %}
<h1>Unavailable</h1>

<p>The page you have requested is currently unavailable, as our site is temporarily offline. Please try again later.</p>
{% endblock %}
